# Release History

## [0.0.3]
**Added**
- Data Event cloud storage writers (Azure, AWS and Databricks mount)

## [0.0.2] - 2023-09-24
**Added**
- Data Event class
- Data Source classes
- Pipeline class
- Support for BRONZE transformations

## [0.0.1] - 2023-07-13
**Added**
- Initial pypi release
